==> hylafax_4.3.1.orig.tar.gz: hylafax-4.3.1/faxd/FaxSendStatus.h <==
/*	$Id: FaxSendStatus.h,v 1.4 2005/09/27 18:33:50 lhoward Exp $ */
/*
 * Copyright (c) 1990-1996 Sam Leffler
 * Copyright (c) 1991-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _FaxSendStatus_
#define	_FaxSendStatus_
/*
 * Status of a send job.
 */
enum FaxSendStatus {
    send_retry,			// waiting for retry
    send_failed,		// finished w/o success
    send_done,			// completed successfully
    send_reformat,		// retry with reformatted documents
    send_v34fail,		// failed due to V.34-Fax trouble
    send_v17fail,		// failed due to V.17-Fax trouble
    send_batchfail		// batch failure, retry
};
#define	send_ok	send_done
#endif /* _FaxSendStatus_ */

==> hylafax_4.4.3.orig.tar.gz: hylafax-4.4.3/faxd/FaxSendStatus.h <==
/*	$Id: FaxSendStatus.h,v 1.5 2007/05/04 17:28:32 aidan Exp $ */
/*
 * Copyright (c) 1990-1996 Sam Leffler
 * Copyright (c) 1991-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _FaxSendStatus_
#define	_FaxSendStatus_
/*
 * Status of a send job.
 */
enum FaxSendStatus {
    send_retry,			// waiting for retry
    send_failed,		// finished w/o success
    send_done,			// completed successfully
    send_reformat,		// retry with reformatted documents
    send_v34fail,		// failed due to V.34-Fax trouble
    send_v17fail,		// failed due to V.17-Fax trouble
    send_batchfail,		// batch failure, retry
    send_nobatch,		// Nothing happend to this job in the batch
};
#define	send_ok	send_done
#endif /* _FaxSendStatus_ */
